/*
 * MademandedachatsSessionBehavior.java
 * Copyright (c) 2012, W4.
 * All rights reserved.
 */

package myOrder.behavior;

import eu.w4.ae.peer.w4.*;
import eu.w4.bpm.*;
import eu.w4.leon.appmodel.appdefault.*;
import eu.w4.leon.appmodel.appdefault.behavior.*;
import eu.w4.leon.appmodel.appdefault.command.*;
import eu.w4.leon.appmodel.appdefault.tools.*;
import java.lang.reflect.*;
import java.rmi.*;
import java.util.*;
import leon.app.*;
import leon.app.behavior.*;
import leon.control.*;
import leon.data.*;
import leon.info.*;
import leon.misc.*;
import leon.peer.*;
import leon.view.*;
import leon.view.setinterface.*;
import leon.view.web.*;

/**
 * This interface defines the methods to implement in order to change the default behavior of a
 * session.
 *
 * @author  W4 S.A.
 * @see     leon.app.LySession
 */
public class MademandedachatsSessionBehavior extends W4SessionBehavior
{
	/**
	 * Default Constructor.
	 * @see eu.w4.leon.appmodel.appdefault.behavior.W4SessionBehavior#W4SessionBehavior
	 */
	public MademandedachatsSessionBehavior()
	{
		super();
	}

	/**
	 * @see LySessionBehavior#validateAction(LySession, LyAction, LyController)
	 * @see eu.w4.leon.appmodel.appdefault.behavior.W4SessionBehavior#validateAction
	 */
	public boolean validateAction(LySession session, LyAction action, LyController controller)
	{
		return super.validateAction(session, action, controller);
	}

	/**
	 * Verify if an action can be accessible to the connected user. The test controls if the action owns a mark on 
	 * user role. The mark follows the format : ROLE_roleName.
	 * @param session Current user session
	 * @param action Action on which the verification is applied
	 * @return true if the user can access to the user, false else.
	 * @see eu.w4.leon.appmodel.appdefault.behavior.W4SessionBehavior#isUserCanAccessToActionDependingOnRole
	 */
	protected boolean isUserCanAccessToActionDependingOnRole(LySession session, LyAction action, String domain)
	{
		return super.isUserCanAccessToActionDependingOnRole(session, action, domain);
	}

	/**
	 * Handle exit
	 * @see eu.w4.leon.appmodel.appdefault.behavior.W4SessionBehavior#messageAnswer
	 */
	public void messageAnswer(int result, Object clientData)
	{
		super.messageAnswer(result, clientData);
	}

	/**
	 * Method called when the user ask to quit the given session.<br />
	 * <i>The default implementation</i>
	 * {@link LyViewManager#askQuestion(leon.view.LyComponent, String, leon.view.setinterface.LyQuestionAnswerInterface, Object) asks confirmation}
	 * to the user before exiting.
	 *
	 * @param  session  Session to exit from
	 * @see eu.w4.leon.appmodel.appdefault.behavior.W4SessionBehavior#exit
	 */
	public void exit(LySession session)
	{
		super.exit(session);
	}

	/**
	 * Perform a log out of the current user with a message indicating that he must reconnect.
	 * @param session the user session.
	 * @see eu.w4.leon.appmodel.appdefault.behavior.W4SessionBehavior#handleLostConnection
	 */
	public void handleLostConnection(LyDataSession session)
	{
		super.handleLostConnection(session);
	}

	/**
	 * Handle connection lost for W4
	 * @see eu.w4.leon.appmodel.appdefault.behavior.W4SessionBehavior#connectionLost
	 */
	public void connectionLost(LyDataSession session, LyInfo server)
	{
		super.connectionLost(session, server);
	}

	/**
	 * Handle all exception thrown during a user session.
	 * This implementation traps all BPM connection exception to perform a logout of the current user/
	 * @see eu.w4.leon.appmodel.appdefault.behavior.W4SessionBehavior#handleException
	 */
	public void handleException(LySession session, Throwable e)
	{
		super.handleException(session, e);
	}

	/**
	 * Method called when a session is closed.<br />
	 * <i>The default implementation</i> only calls {@link LySession#confirmClosing()} method.
	 *
	 * @param session the closed session.
	 * @see eu.w4.leon.appmodel.appdefault.behavior.W4SessionBehavior#close
	 */
	public void close(LySession session)
	{
		super.close(session);
	}

	/**
	 * Get a user from its login
	 * @param session the current session
	 * @param login the login
	 * @return a user if the login is correct
	 * @see eu.w4.leon.appmodel.appdefault.behavior.W4SessionBehavior#getUserFromLogin
	 */
	public LyObject getUserFromLogin(LyDataSession session, String login)
	{
		return super.getUserFromLogin(session, login);
	}

	/**
	 * Check if the current user has a role on a domain.
	 * To enhance performance, the result is store on a hashmap
	 * @param session the current session
	 * @param roleName the role name
	 * @param domainName the domain name
	 * @return true is the user has the role on the domain. False otherwise
	 * @see eu.w4.leon.appmodel.appdefault.behavior.W4SessionBehavior#hasRole
	 */
	public boolean hasRole(LySession session, String roleName, String domainName)
	{
		return super.hasRole(session, roleName, domainName);
	}
}
