/*
 * PurchaseorderClassBehavior.java
 * Copyright (c) 2011, W4.
 * All rights reserved.
 */

package myOrder.behavior;

import java.util.*;
import leon.app.behavior.*;
import leon.app.behaviorinterface.*;
import leon.control.*;
import leon.data.*;
import leon.info.*;
import leon.info.save.*;
import leon.view.event.*;

/**
 * Generic interface for all behaviors that applies on action. This interface represents the default
 * behavior for consult, set, filter and delete actions.
 *
 * @author  Lyria S.A.
 * @version $Id: LyClassBehaviorInterface.java 28422 2010-11-03 12:03:38Z ehelmste $
 * @see     leon.app.behaviorinterface.LySetBehaviorInterface
 * @see     leon.app.behaviorinterface.LyCreateBehaviorInterface
 * @see     leon.app.behaviorinterface.LyDeleteBehaviorInterface
 * @see     leon.app.behaviorinterface.LyFilterBehaviorInterface
 */
public class PurchaseorderClassBehavior extends LyClassBehavior
{
	/**
	 * Default Constructor
	 */
	public PurchaseorderClassBehavior()
	{
	}

	/**
	 * Information used within this behavior are initialized here. This method is called immediately
	 * after the behavior construction.
	 *
	 * @param controller The controller that requested the creation of this behavior.
	 * @see leon.app.behaviorinterface.LyBehaviorInterface#init
	 */
	public void init(LyController controller)
	{
		super.init(controller);
	}

	/**
	 * Free this behavior. This method is provided to allow behavior to unregister itself from
	 * object sources or workspaces if needed. It should be called only by the controller that built
	 * this behavior.
	 * @see leon.app.behaviorinterface.LyBehaviorInterface#free
	 */
	public void free()
	{
		super.free();
	}

	/**
	 * Invoked when a demand is sent to this listener.
	 *
	 * @param  controller controller that routed the demand.
	 * @param  demand     demand parameters sent by the view component.
	 * @return Return true if the demand was handled, false otherwise. If false, the demand is
	 *         transmitted to the controller to try to handle it.
	 * @see leon.app.behaviorinterface.LyBehaviorInterface#handleDemand
	 */
	public boolean handleDemand(LyController controller, LyDemand demand)
	{
		return super.handleDemand(controller, demand);
	}

	/**
	 * Starts an action for the given controller. This method is the right place to allocate
	 * specific resources requiered for the given action.
	 *
	 * @param  areaController the current LyAreaController instance
	 * @param  action         the action that will be executed
	 * @return true if the action starts correctly, false otherwise.
	 * @see leon.app.behaviorinterface.LyActionBehaviorInterface#startAction
	 */
	public boolean startAction(LyAreaController areaController, LyAction action)
	{
		return super.startAction(areaController, action);
	}

	/**
	 * The controller resets its content. This method is the right place to add extra processing
	 * when the view is set.
	 *
	 * @param  areaController the current LyAreaController instance
	 * @param  full           indicates if the controller performed a full reset of its content or a
	 *                        partial reset. The meaning of a full reset depends on controller
	 *                        implementation.
	 * @return true if the action starts correctly, false otherwise.
	 * @see leon.app.behaviorinterface.LyActionBehaviorInterface#reset
	 */
	public boolean reset(LyAreaController areaController, boolean full)
	{
		return super.reset(areaController, full);
	}

	/**
	 * Ends an action for the given controller. This method is the right place to free specific
	 * resources allocated for the given action.
	 *
	 * @param  areaController the current LyAreaController instance
	 * @param  action         the action that was executed
	 * @return true if the action performed correctly, false otherwise
	 * @see leon.app.behaviorinterface.LyActionBehaviorInterface#endAction
	 */
	public boolean endAction(LyAreaController areaController, LyAction action)
	{
		return super.endAction(areaController, action);
	}

	/**
	 * Gets the image corresponding to the given object for the given controller. This image is
	 * mostly used in titlebar.
	 *
	 * @param  areaController controller for which the image is required.
	 * @param  action         the action that was executed
	 * @return Logical name of the image for the given action or null to let controller do the job.
	 *         The string "_null" means no image.
	 * @see leon.app.behaviorinterface.LyActionBehaviorInterface#getImage
	 */
	public String getImage(LyAreaController areaController, LyAction action)
	{
		return super.getImage(areaController, action);
	}

	/**
	 * Gets image tooltip corresponding to the given action.
	 *
	 * @param  areaController the current LyAreaController instance
	 * @param  action         the action that was executed
	 * @return image tooltip for the given action.
	 * @see leon.app.behaviorinterface.LyActionBehaviorInterface#getImageTooltip
	 */
	public String getImageTooltip(LyAreaController areaController, LyAction action)
	{
		return super.getImageTooltip(areaController, action);
	}

	/**
	 * Gets the menu image corresponding to the given action for the given controller.
	 *
	 * @param  areaController The controller for which the image is required.
	 * @param  action         The action for which the image is required
	 * @return Logical name of the image for the given action or null to let controller do the job.
	 *         The string "_null" means no image.
	 * @see leon.app.behaviorinterface.LyActionBehaviorInterface#getMenuItemImage
	 */
	public String getMenuItemImage(LyAreaController areaController, LyAction action)
	{
		return super.getMenuItemImage(areaController, action);
	}

	/**
	 * Gets title corresponding to the given action.
	 *
	 * @param  areaController the current LyAreaController instance
	 * @param  action         the action that was executed
	 * @return Title for the given action or null to let controller do the job.
	 * @see leon.app.behaviorinterface.LyActionBehaviorInterface#getTitle
	 */
	public String getTitle(LyAreaController areaController, LyAction action)
	{
		return super.getTitle(areaController, action);
	}

	/**
	 * Gets title corresponding to the given action and context (sub-title displayed on the right of
	 * the titlebar).
	 *
	 * @param  areaController the current controller instance
	 * @param  action         the action that was executed
	 * @param  context        the action context
	 * @return Context title for the given action or null to let controller do the job.
	 * @see leon.app.behaviorinterface.LyActionBehaviorInterface#getContextTitle
	 */
	public String getContextTitle(LyAreaController areaController, LyAction action,
		LyObjectList context)
	{
		return super.getContextTitle(areaController, action, context);
	}

	/**
	 * Gets help file for the given action.
	 *
	 * @param  areaController the current controller instance
	 * @param  action         the action that was executed
	 * @return Help file for the given action or null to let controller do the job.
	 * @see leon.app.behaviorinterface.LyActionBehaviorInterface#getHelpFile
	 */
	public String getHelpFile(LyAreaController areaController, LyAction action)
	{
		return super.getHelpFile(areaController, action);
	}

	/**
	 * Gets context to set on the controllers that have the given area controller as context.
	 *
	 * @param  areaController the current controller instance.
	 * @param  context  the context that is about to be set.
	 * @return The desired client context.
	 * @see leon.app.behaviorinterface.LyActionBehaviorInterface#getClientContext
	 */
	public LyObjectList getClientContext(LyAreaController areaController, LyObjectList context)
	{
		return super.getClientContext(areaController, context);
	}

    /**
     * Retrieves a value from a registered key.
     *
     * @param   key  The key that must be used.
     * @return  The value stored with the key or null if the key is not registered.
	 * @see leon.app.behaviorinterface.LyActionBehaviorInterface#getKeyValue
     */
    public Object getKeyValue(String key)
	{
		return super.getKeyValue(key);
	}

	/**
	 * Gets the image associated to the given object for the given form.
	 *
	 * @param  formController the form controller
	 * @param  object         object whose image is looked for
	 * @return Logical name of the image.
	 * @see leon.app.behaviorinterface.LyFormBehaviorInterface#getImage
	 */
	public String getImage(LyFormController formController, LyObject object)
	{
		return super.getImage(formController, object);
	}

	/**
	 * Gets value of the given fieldInfo. This method must be efficient because it can be called
	 * frequently.
	 *
	 * @param  form      the current LyFormController instance.
	 * @param  fieldInfo the fieldInfo that contains the value
	 * @return the value of the given fieldInfo as an Object
	 * @see leon.app.behaviorinterface.LyFormBehaviorInterface#getValue
	 */
	public Object getValue(LyFormController form, LyFieldInfo fieldInfo)
	{
		return super.getValue(form, fieldInfo);
	}

	/**
	 * Indicates if the given fieldInfo is displayed in the given form or not.
	 *
	 * @param  form      the current LyFormController instance.
	 * @param  fieldInfo the fieldInfo which is tested for addition in the view.
	 * @return true if the field should be added, false if it should be skipped.
	 * @see leon.app.behaviorinterface.LyFormBehaviorInterface#isDisplayed
	 */
	public boolean isDisplayed(LyFormController form, LyFieldInfo fieldInfo)
	{
		return super.isDisplayed(form, fieldInfo);
	}

	/**
	 * Gets action to use for consulting or editing the given relation with the specified class info
	 * selected on it.
	 *
	 * @param  consult   the current LyConsultController instance.
	 * @param  relation  Edited relation
	 * @param  classInfo Selected class info.
	 * @return The action to use, if null let controller decides.
	 * @see leon.app.behaviorinterface.LyConsultBehaviorInterface#getAction
	 */
	public LyAction getAction(LyConsultController consult, LyRelationFieldInfo relation,
		LyClassInfo classInfo)
	{
		return super.getAction(consult, relation, classInfo);
	}

	/**
	 * Method called when object shown in the form is changed.
	 *
	 * @param consult the current LyConsultController instance.
	 * @param object  the object shown in the form.
	 * @see leon.app.behaviorinterface.LyConsultBehaviorInterface#setObject
	 */
	public void setObject(LyConsultController consult, LyObject object)
	{
		super.setObject(consult, object);
	}

    /**
     * Enables the given href object on the given relation field info.<br />
     * <i>The default implementation</i> always returns true.
     *
     * @param  consult  the current LyConsultController instance
     * @param  relation the relation that contains the href
     * @param  href     the href to enabled
     * @return true if the href is enabled on this relation, false otherwise
	 * @see leon.app.behaviorinterface.LyConsultBehaviorInterface#enableRelationHRef
     */
	public    boolean enableRelationHRef(LyConsultController consult, LyRelationFieldInfo relation,
        LyObject href)
	{
		return super.enableRelationHRef(consult, relation, href);
	}

	/**
	 * Checks if the given fieldInfo is optional or not for the given controller.
	 *
	 * @param  set       the current LySetController instance
	 * @param  fieldInfo the target fieldInfo to test
	 * @return true if the given fieldInfo is optional, false otherwise
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#isOptional
	 */
	public boolean isOptional(LySetController set, LyFieldInfo fieldInfo)
	{
		return super.isOptional(set, fieldInfo);
	}

	/**
	 * Checks if the given fieldInfo is editable or not for the given controller.
	 *
	 * @param  set       the current LySetController instance
	 * @param  fieldInfo the target fieldInfo to test
	 * @return true if the given fieldInfo is editable, false otherwise
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#isEditable
	 */
	public boolean isEditable(LySetController set, LyFieldInfo fieldInfo)
	{
		return super.isEditable(set, fieldInfo);
	}

	/**
	 * Checks if the given fieldInfo is enabled or not for the given controller.
	 *
	 * @param  set       the current LySetController instance
	 * @param  fieldInfo the target fieldInfo to test
	 * @return true if the given fieldInfo is enabled, false otherwise
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#isEnabled
	 */
	public boolean isEnabled(LySetController set, LyFieldInfo fieldInfo)
	{
		return super.isEnabled(set, fieldInfo);
	}

	/**
	 * Indicates the maximum number of values displayed in text components for auto-completion.
	 *
	 * @param  set       the current LySetController instance.
	 * @param  fieldInfo the target text fieldInfo to test.
	 * @return a positive number if auto-completion is activated, 0 if auto-completion is not
	 *         activated, a negative value if there is no maximum.
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#getAutoCompletionMaximum
	 */
	public int getAutoCompletionMaximum(LySetController set, LyTextFieldInfo fieldInfo)
	{
		return super.getAutoCompletionMaximum(set, fieldInfo);
	}

	/**
	 * Computes the list of values displayed in text components for auto-completion.
	 *
	 * @param  set       the current LySetController instance.
	 * @param  fieldInfo the target text fieldInfo to test.
	 * @return the list of values for auto-completion.
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#getAutoCompletionValues
	 */
	public String[] getAutoCompletionValues(LySetController set, LyTextFieldInfo fieldInfo)
	{
		return super.getAutoCompletionValues(set, fieldInfo);
	}

	/**
	 * Gets domain (list of allowed options) of the given choice fieldInfo.
	 *
	 * @param  set    the current LySetController instance
	 * @param  choice target choice fieldInfo
	 * @return the list of {@link leon.info.LyChoiceOption} allowed for this choice field info
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#getChoiceDomain
	 */
	public Vector<LyChoiceOption> getChoiceDomain(LySetController set, LyChoiceFieldInfo choice)
	{
		return super.getChoiceDomain(set, choice);
	}

	/**
	 * Checks if the given options group is valid for the given option of the choice fieldinfo.
	 *
	 * @param  set    the current set controller
	 * @param  choice the choice fieldInfo
	 * @param  option the choiceOption
	 * @param  group  the choiceOption group
	 * @return true if the group is valid, false otherwise.
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#isValidGroup
	 */
	public boolean isValidGroup(LySetController set, LyChoiceFieldInfo choice,
		LyChoiceOption option, LyChoiceOptionGroup group)
	{
		return super.isValidGroup(set, choice, option, group);
	}

	/**
	 * Indicates if the given option is enabled on the given choice fieldInfo.
	 *
	 * @param  set    the current LySetController instance
	 * @param  choice choiceFieldInfo that contains this option
	 * @param  option the option to enabled
	 * @return true if the option is enabled, false otherwise
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#enableChoiceOption
	 */
	public boolean enableChoiceOption(LySetController set, LyChoiceFieldInfo choice,
		LyChoiceOption option)
	{
		return super.enableChoiceOption(set, choice, option);
	}

    /**
     * Indicates if the given option is hidden on the given choice fieldInfo.<br />
     * <i>The default implementation</i> checks if the option is not disabled.
     *
     * @param  set    the current LySetController instance
     * @param  choice choiceFieldInfo that contains this option
     * @param  option the option to check
     * @return true if the option is hidden, false otherwise
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#validateChoiceOption
     */
	public    boolean validateChoiceOption(LySetController set, LyChoiceFieldInfo choice,
        LyChoiceOption option)
	{
		return super.validateChoiceOption(set, choice, option);
	}

	/**
	 * Gets relation domain (list of available links) for the given relation fieldInfo.
	 *
	 * @param  set      the current LySetController instance
	 * @param  relation the target relation field
	 * @return a list of LyObjects available for this relation
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#getRelationDomain
	 */
	public LyObjectList getRelationDomain(LySetController set, LyRelationFieldInfo relation)
	{
		return super.getRelationDomain(set, relation);
	}

	/**
	 * Allows the given link object as a possible value for the given relation field info.
	 *
	 * @param  set       the current LySetController instance
	 * @param  relation  the relation that contains the link
	 * @param  link      the link to enabled
	 * @param  showError indicates if an error should be shown if the given link is rejected.
	 * @return true if the link is enabled on this relation, false otherwise
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#enableRelationLink
	 */
	public boolean enableRelationLink(LySetController set, LyRelationFieldInfo relation,
		LyObject link, boolean showError)
	{
		return super.enableRelationLink(set, relation, link, showError);
	}

	/**
	 * Allows the given link object as a possible value for the given relation field info.
	 *
	 * @param  set      the current LySetController instance
	 * @param  relation the relation that contains the link
	 * @param  link     the link to enabled
	 * @return true if the link is enabled on this relation, false otherwise
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#enableRelationLink
	 */
	public boolean enableRelationLink(LySetController set, LyRelationFieldInfo relation,
		LyObject link)
	{
		return super.enableRelationLink(set, relation, link);
	}

	/**
	 * Gets the list of available classInfo of the given relation fieldInfo.
	 *
	 * @param  set      the current LySetController instance
	 * @param  relation the target relation fieldInfo
	 * @return the list of classInfo available for this relation
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#getRelationClasses
	 */
	public LyInfoList<LyClassInfo> getRelationClasses(LySetController set, LyRelationFieldInfo relation)
	{
		return super.getRelationClasses(set, relation);
	}

	/**
	 * Gets?the list of objects of the given relation context.
	 *
	 * @param  set      the current LySetController instance
	 * @param  relation the target relation fieldInfo
	 * @return a list of LyObject available in this relation field
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#getRelationContext
	 */
	public LyObjectList getRelationContext(LySetController set, LyRelationFieldInfo relation)
	{
		return super.getRelationContext(set, relation);
	}

	/**
	 * Indicates the maximum number of values displayed in relation components for auto-completion.
	 * 
	 * @param  set       the current LySetController instance.
	 * @param  relation  the target relation fieldInfo to test.
	 * @return a positive number if auto-completion is activated, 0 if auto-completion is not
	 *         activated, a negative value if there is no maximum.
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#getAutoCompletionMaximum
	 */
	public int getAutoCompletionMaximum(LySetController set, LyRelationFieldInfo relation)
	{
		return super.getAutoCompletionMaximum(set, relation);
	}

	/**
	 * Gets relation domain (list of available links) for the given relation fieldInfo with the
	 * given prefix for related objects.
	 *
	 * @param  set      the current LySetController instance
	 * @param  relation the target relation field
	 * @param  prefix   the prefix for related objects
	 * @param  fill     indicates whether the domain must be filtered with given prefix or not
	 * @return a list of LyObjects available for this relation and given prefix
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#getRelationDomain
	 */
	public LyObjectList getRelationDomain(LySetController set, LyRelationFieldInfo relation, String prefix, boolean fill)
	{
		return super.getRelationDomain(set, relation, prefix, fill);
	}

	/**
	 * Gets the short label that must be used for the given relation fieldInfo.
	 * 
	 * @param set      the current LySetController instance
	 * @param relation the target relation field
	 * @param link     the object represented by the link
	 * @return the short name of the link (displayed when selected) or null if no short label must be used
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#getLinkShortLabel
	 */
	public String getLinkShortLabel(LySetController set, LyRelationFieldInfo relation, LyObject link)
	{
		return super.getLinkShortLabel(set, relation, link);
	}

	/**
	 * Indicates if auto-completion on the given relation fieldInfo is managed by the graphical
	 * component or by the field controller.
	 *
	 * @param  set       the current LySetController instance
	 * @param  relation  the fieldInfo that may need to be checked
	 * @return true if auto-completion is managed by the graphical component, false otherwise
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#useLocalCompletion
	 */
	public boolean useLocalCompletion(LySetController set, LyRelationFieldInfo relation)
	{
		return super.useLocalCompletion(set, relation);
	}

	/**
	 * Gets actions enabled by the given relation. A list of pairs (action, classInfo) has to be
	 * returned.
	 *
	 * @param  set      the current LySetController instance
	 * @param  relation the relation that may enabled some actions
	 * @return the list of actions enabled by the given relation
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#getTransverseActions
	 */
	public LyInfoDataList<LyAction, LyClassInfo> getTransverseActions(LySetController set, LyRelationFieldInfo relation)
	{
		return super.getTransverseActions(set, relation);
	}

	/**
	 * Gets actions enabled by the given field. A list of pairs (action, classInfo) has to be
	 * returned.
	 *
	 * @param  set       the current LySetController instance
	 * @param  fieldInfo the field that may enabled some actions
	 * @return a list of actions enabled by the given field
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#getTransverseActions
	 */
	public LyInfoDataList<LyAction, LyClassInfo> getTransverseActions(LySetController set, LyFieldInfo fieldInfo)
	{
		return super.getTransverseActions(set, fieldInfo);
	}

	/**
	 * Gets the default value of the given fieldInfo. This method can be called:
	 *
	 * <ul>
	 *   <li>to initialize an input field in a creation form</li>
	 *   <li>to get a value for an empty input field that becomes mandatory</li>
	 *   <li>to get a value for notNull fields at the end of the creation process</li>
	 * </ul>
	 *
	 * @param  set       the current LySetController instance.
	 * @param  fieldInfo the fieldInfo that contains the value.
	 * @return the value of the given fieldInfo as an Object
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#getDefaultValue
	 */
	public Object getDefaultValue(LySetController set, LyFieldInfo fieldInfo)
	{
		return super.getDefaultValue(set, fieldInfo);
	}

	/**
	 * Indicates if the given fieldInfo needs to be checked when the value is modified (in creation
	 * and set mode).
	 *
	 * @param  set       the current LySetController instance
	 * @param  fieldInfo the fieldInfo that may need to be checked
	 * @return true if the field need to be checked, false otherwise
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#needCheck
	 */
	public boolean needCheck(LySetController set, LyFieldInfo fieldInfo)
	{
		return super.needCheck(set, fieldInfo);
	}

	/**
	 * Progates modifications of the given field on all other fields. Propagate modidication of a
	 * fieldInfo with the given value on other fields.
	 *
	 * @param set      the current LySetController instance
	 * @param newValue new field info value to propagate
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#propagate
	 */
	public void propagate(LySetController set, LyFieldInfoValue newValue)
	{
		super.propagate(set, newValue);
	}

	/**
	 * This method controls the given value before creating or modifying an object. It does not
	 * checks its content but the coherence between it and its field marks.
	 *
	 * @param  set      the current LySetController instance
	 * @param  newValue field info value to check. This value cannot be null.
	 * @return a code to indicates the control result. Possible values are:
	 *
	 *         <ul>
	 *           <LI>{@link #STATUS_IGNORE} if the value has not change</LI>
	 *           <LI>{@link #STATUS_OK} if the value is correct</LI>
	 *           <LI>{@link #STATUS_KO} if the value is not correct</LI>
	 *           <LI>{@link #STATUS_WARNING} if the value is on warning</LI>
	 *         </ul>
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#controlNewValue
	 */
	public short controlNewValue(LySetController set, LyFieldInfoValue newValue)
	{
		return super.controlNewValue(set, newValue);
	}

	/**
	 * Dynamicaly checks the given value for its associated field. This method is called when there
	 * is a modification of the field in the user interface (Value changed, focus lost...).
	 *
	 * @param  set      the current LySetController instance
	 * @param  newValue field info value to check.
	 * @return a code to indicates the check result. Possible values are:
	 *
	 *         <ul>
	 *           <LI>STATUS_KO if the value is not correct</LI>
	 *           <LI>STATUS_OK if the value is correct</LI>
	 *         </ul>
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#checkNewValue
	 */
	public short checkNewValue(LySetController set, LyFieldInfoValue newValue)
	{
		return super.checkNewValue(set, newValue);
	}

	/**
	 * Global control of values before creating or modifying an object. If needed, extra values may
	 * be added during this control.
	 *
	 * @param  set       the current LySetController instance
	 * @param  newValues Set of values to control
	 * @return
	 *
	 *         <ul>
	 *           <LI>STATUS_IGNORE if the value has not change</LI>
	 *           <LI>STATUS_KO if the value is not correct</LI>
	 *           <LI>STATUS_OK if the value is correct</LI>
	 *         </ul>
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#controlNewValues
	 */
	public short controlNewValues(LySetController set, LyValueSet newValues)
	{
		return super.controlNewValues(set, newValues);
	}

	/**
	 * This method adds the given extra values before completing the current operation.
	 *
	 * @param set    the current LySetController instance
	 * @param values Current set of values. Additionnal values must be add to this set
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#addExtraValues
	 */
	public void addExtraValues(LySetController set, LyValueSet values)
	{
		super.addExtraValues(set, values);
	}

	/**
	 * Final step of object set process.
	 *
	 * @param  set    the current LySetController instance
	 * @param  values Set of values for the modified object
	 * @return true if the modification process is done, false otherwise
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#endSet
	 */
	public boolean endSet(LySetController set, LyValueSet values)
	{
		return super.endSet(set, values);
	}

	/**
	 * Gets the filter of the given relation and the given class.<br />
	 * This method is used by the {@link #getRelationDomain(LySetController, LyRelationFieldInfo)}
	 * method when the target objets of the relation need to be filtered.
	 *
	 * @param  controller the current LyController instance
	 * @param  relation   the relation field info we want to filter
	 * @param  classInfo  ClassInfo for which we look for an associated filter.
	 * @return The filter associated to the given classInfo, or null if no filter has been specified
	 *         for this classInfo in this relation.
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#getRelationFilter
	 */
	public LyFilter getRelationFilter(LySetController controller, LyRelationFieldInfo relation,
		LyClassInfo classInfo)
	{
		return super.getRelationFilter(controller, relation, classInfo);
	}

	/**
	 * Checks if an edit table should be used for the given array field.
	 *
	 * @param  controller The current LySetController instance.
	 * @param  array      The array field info.
	 * @return True if an edit table is requested, false otherwise.
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#useEditTable
	 */
	public boolean useEditTable(LySetController controller, LyArrayFieldInfo array)
	{
		return super.useEditTable(controller, array);
	}

	/**
	 * Checks if an edit table should be used for the given relation field.
	 *
	 * @param  controller The current LySetController instance.
	 * @param  relation   The relation field info.
	 * @return True if an edit table is requested, false otherwise.
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#useEditTable
	 */
	public boolean useEditTable(LySetController controller, LyRelationFieldInfo relation)
	{
		return super.useEditTable(controller, relation);
	}

	/**
	 * Invoked when controller is starting to commit, default implementation does nothing
	 * @param  controller The current LySetController instance.
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#startCommit
	 */
	public void startCommit(LySetController controller)
	{
		super.startCommit(controller);
	}

	/**
	 * Invoked when controller is ending commit, default implementation does nothing
	 * @param  controller The current LySetController instance.
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#endCommit
	 */
	public void endCommit(LySetController controller)
	{
		super.endCommit(controller);
	}

	/**
     * Indicates if the operations of the controller context must be inserted at the beginning of the parent
     * operations or at the end.
     * 
     * @param controller the set controller
     * @param relation the relation field
     * @return Position where operations must be inserted, may be null if left to controller decision.
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#getInsertPosition
     */
	public LyContext.Position getInsertPosition(LySetController controller, LyRelationFieldInfo relation)
	{
		return super.getInsertPosition(controller, relation);
	}

    /**
     * Method called on form save.
     * @param  controller The current LySetController instance.
     * @param  formSave The formSave that was created.
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#formSaved
     */
	public void formSaved(LySetController controller, LyFormSave formSave)
	{
		super.formSaved(controller, formSave);
	}

    /**
     * Method called on form restore.
     * @param  controller The current LySetController instance.
     * @param  formSave The formSave that was restored.
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#formRestored
     */
	public void formRestored(LySetController controller, LyFormSave formSave)
	{
		super.formRestored(controller, formSave);
	}

    /**
     * Indicates if the given controller must link its context to its parent context
     * @param  controller The current LySetController instance.
     * @param parentRelation the parent relation for this controller (may be null)
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#useSingleContext
     */
	public boolean useSingleContext(LySetController controller, LyRelationFieldInfo parentRelation)
	{
		return super.useSingleContext(controller, parentRelation);
	}

    /**
     * Checks if given object is locked for edition.
     * @param controller The current LySetController instance.
     * @param object Object to be checked.
     * @return Null if not locked, otherwise a string message giving information about the lock (user, date...).
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#isLocked
     */
	public String isLocked(LySetController controller, LyObject object)
	{
		return super.isLocked(controller, object);
	}

    /**
     * Locks/Unlocks given object for edition.
     * @param controller The current LySetController instance.
     * @param object Object to be locked/unlocked.
     * @param lock True if lock is required, false for unlock.
     * @return True if successful, false otherwise.
	 * @see leon.app.behaviorinterface.LySetBehaviorInterface#lockObject
     */
	public boolean lockObject(LySetController controller, LyObject object, boolean lock)
	{
		return super.lockObject(controller, object, lock);
	}

	/**
	 * Final step of the object creation process.
	 *
	 * @param  create the current LyCreateController instance
	 * @param  values Set of values corresponding to the object to create
	 * @return true if the create process is successfull, false otherwise
	 * @see leon.app.behaviorinterface.LyCreateBehaviorInterface#endCreation
	 */
	public boolean endCreation(LyCreateController create, LyValueSet values)
	{
		return super.endCreation(create, values);
	}

	/**
	 * Checks if the given object deletion is enabled or not (used before asking to the end-user if
	 * he want to delete).
	 *
	 * @param  delete current LyDeleteController instance
	 * @param  object Object checked before deletion.
	 * @return Error message if deletion is not allowed, null otherwise.
	 * @see leon.app.behaviorinterface.LyDeleteBehaviorInterface#checkDeletion
	 */
	public String checkDeletion(LyDeleteController delete, LyObject object)
	{
		return super.checkDeletion(delete, object);
	}

	/**
	 * hecks if the given objects list deletion is enabled or not (used before asking to the
	 * end-user if he want to delete them).
	 *
	 * @param  delete current LyDeleteController instance
	 * @param  list   list of objects to checked before deletion.
	 * @return The list of allowed objects to delete.
	 * @see leon.app.behaviorinterface.LyDeleteBehaviorInterface#checkDeletions
	 */
	public LyObjectList checkDeletions(LyDeleteController delete, LyObjectList list)
	{
		return super.checkDeletions(delete, list);
	}

	/**
	 * Asks for the deletion message for the given object.
	 *
	 * @param  delete current LyDeleteController instance
	 * @param  object Object checked before deletion.
	 * @return Confirmation message to display to the user if necessary, null otherwise.
	 * @see leon.app.behaviorinterface.LyDeleteBehaviorInterface#getConfirmDeletionMessage
	 */
	public String getConfirmDeletionMessage(LyDeleteController delete, LyObject object)
	{
		return super.getConfirmDeletionMessage(delete, object);
	}

	/**
	 * Final step of object deletion process.
	 *
	 * @param  delete current LyDeleteController instance
	 * @return true if the deletion is complete, false otherwise
	 * @see leon.app.behaviorinterface.LyDeleteBehaviorInterface#endDeletion
	 */
	public boolean endDeletion(LyDeleteController delete)
	{
		return super.endDeletion(delete);
	}

	/**
	 * Gets relation domain (list of available links in the filter context) for the given relation
	 * fieldInfo for filter actions.
	 *
	 * @param  filter   the current LyFilterController instance
	 * @param  relation the target relation field
	 * @return a list of LyObjects available for this relation in filtering context.
	 * @see leon.app.behaviorinterface.LyFilterBehaviorInterface#getFilterRelationDomain
	 */
	public LyObjectList getFilterRelationDomain(LyFilterController filter,
		LyRelationFieldInfo relation)
	{
		return super.getFilterRelationDomain(filter, relation);
	}

	/**
	 * Gets the list of available class info for the given relation filtering.
	 *
	 * @param  filter   the current instance of "filter controller" This parameter could be both a
	 *                  LyFilterController or a LyFilterRelationController. That's why its type is
	 *                  LyFormController which is the common inheritance.
	 * @param  relation the target relation field
	 * @return a list of classInfo available for filtering the relation
	 * @see leon.app.behaviorinterface.LyFilterBehaviorInterface#getFilterRelationClasses
	 */
	public LyInfoList<LyClassInfo> getFilterRelationClasses(LyFormController filter, LyRelationFieldInfo relation)
	{
		return super.getFilterRelationClasses(filter, relation);
	}

	/**
	 * Gets all actions enabled by the given field for a filter action. A list of pairs (action,
	 * classInfo) has to be returned.
	 *
	 * @param  filter   the current LyFilterController instance
	 * @param  fieldInfo the field that may enabled some actions
	 * @return a list of actions enabled by the given field for a filter action
	 * @see leon.app.behaviorinterface.LyFilterBehaviorInterface#getFilterTransverseActions
	 */
	public LyInfoDataList<LyAction, LyClassInfo> getFilterTransverseActions(LyFilterController filter,
		LyFieldInfo fieldInfo)
	{
		return super.getFilterTransverseActions(filter, fieldInfo);
	}

	/**
	 * Gets all actions enabled by the given relation for a filter action. A list of pairs (action,
	 * classInfo) has to be returned.
	 *
	 * @param  filter   the current LyFilterController instance
	 * @param  relation the relation that may enabled some actions
	 * @return a list of actions enabled by the given relation for a filter action
	 * @see leon.app.behaviorinterface.LyFilterBehaviorInterface#getFilterTransverseActions
	 */
	public LyInfoDataList<LyAction, LyClassInfo> getFilterTransverseActions(LyFilterController filter,
		LyRelationFieldInfo relation)
	{
		return super.getFilterTransverseActions(filter, relation);
	}

	/**
	 * Gets domain (list of allowed options) of the given choice fieldInfo.
	 *
	 * @param  filter the current LyFilterController instance
	 * @param  choice target choice fieldInfo
	 * @return a list of LyChoiceOption allowed for this choice field info
	 * @see leon.app.behaviorinterface.LyFilterBehaviorInterface#getFilterChoiceDomain
	 */
	public Vector<LyChoiceOption> getFilterChoiceDomain(LyFilterController filter,
		LyChoiceFieldInfo choice)
	{
		return super.getFilterChoiceDomain(filter, choice);
	}

	/**
	 * Builds a filter element with the given parameters.
	 *
	 * @param  filter    the current LyFilterController instance
	 * @param  fieldInfo FieldInfo on which this filter expression applies.
	 * @param  not       Inverts filter condition or not.
	 * @param  condition Filter condition.
	 * @param  value     Value of this expression (may be null). This value is an instance of the
	 *                   class returned by the getValueClass method of LyFieldInfo.
	 * @param  modifiers List of modifiers (may be null).
	 * @return The corresponding filter element or null if nothing specific must be done
	 * @see leon.app.behaviorinterface.LyFilterBehaviorInterface#buildFilterElement
	 */
	public LyFilterElement buildFilterElement(LyFilterController filter, LyFieldInfo fieldInfo,
		boolean not, LyFilterExpression.Condition condition, Object value, BitSet modifiers)
	{
		return super.buildFilterElement(filter, fieldInfo, not, condition, value, modifiers);
	}

	/**
	 * Get action used for fast edition of given field.
	 *
	 * @param  outline   the current LyOutlineController instance.
	 * @param  fieldInfo the fieldInfo to be edited.
	 * @return The action to be used for fast editing or null if field id not editable.
	 * @see leon.app.behaviorinterface.LyOutlineBehaviorInterface#getSetAction
	 */
	public LyAction getSetAction(LyOutlineController outline, LyFieldInfo fieldInfo)
	{
		return super.getSetAction(outline, fieldInfo);
	}
}
